@@ -38,7 +38,15 @@
 ;; ... and add it to the method list.
 ;;;###tramp-autoload
 (unless (memq system-type '(cygwin windows-nt))
-  (add-to-list 'tramp-methods (cons tramp-smb-method nil)))
+  (add-to-list 'tramp-methods
+    `(,tramp-smb-method
+      ;; We define an empty command, because `tramp-smb-call-winexe'
+      ;; opens already the powershell.  Used in `tramp-handle-shell-command'.
+      (tramp-remote-shell "")
+      ;; This is just a guess.  We don't know whether the share "$C"
+      ;; is available for public use, and whether the user has write
+      ;; access.
+      (tramp-tmpdir "/C$/Temp"))))
 
 ;; Add a default for `tramp-default-method-alist'. Rule: If there is
 ;; a domain in USER, it must be the SMB method.
@@ -74,8 +82,8 @@ call, letting the SMB client use the default one."
 (defvar tramp-smb-version nil
   "*Version string of the SMB client.")
 
-(defconst tramp-smb-prompt "^smb: .+> \\|^\\s-+Server\\s-+Comment$"
-  "Regexp used as prompt in smbclient.")
+(defconst tramp-smb-prompt "^\\(smb:\\|PS\\) .+> \\|^\\s-+Server\\s-+Comment$"
+  "Regexp used as prompt in smbclient or powershell.")
 
 (defconst tramp-smb-errors
   (mapconcat
@@ -98,7 +106,8 @@ call, letting the SMB client use the default one."
 	 "ERRnomem"
 	 "ERRnosuchshare"
 	 ;; Windows 4.0 (Windows NT), Windows 5.0 (Windows 2000),
-	 ;; Windows 5.1 (Windows XP), Windows 5.2 (Windows Server 2003).
+	 ;; Windows 5.1 (Windows XP), Windows 5.2 (Windows Server 2003),
+	 ;; Windows 6.0 (Windows Vista), Windows 6.1 (Windows 7).
 	 "NT_STATUS_ACCESS_DENIED"
 	 "NT_STATUS_ACCOUNT_LOCKED_OUT"
 	 "NT_STATUS_BAD_NETWORK_NAME"
@@ -107,6 +116,7 @@ call, letting the SMB client use the default one."
 	 "NT_STATUS_DIRECTORY_NOT_EMPTY"
 	 "NT_STATUS_DUPLICATE_NAME"
 	 "NT_STATUS_FILE_IS_A_DIRECTORY"
+	 "NT_STATUS_IMAGE_ALREADY_LOADED"
 	 "NT_STATUS_IO_TIMEOUT"
 	 "NT_STATUS_LOGON_FAILURE"
 	 "NT_STATUS_NETWORK_ACCESS_DENIED"
@@ -195,12 +205,14 @@ See `tramp-actions-before-shell' for more info.")
     (make-directory . tramp-smb-handle-make-directory)
     (make-directory-internal . tramp-smb-handle-make-directory-internal)
     (make-symbolic-link . tramp-smb-handle-make-symbolic-link)
+    (process-file . tramp-smb-handle-process-file)
     (rename-file . tramp-smb-handle-rename-file)
     (set-file-modes . tramp-smb-handle-set-file-modes)
     ;; `set-file-selinux-context' performed by default handler.
     (set-file-times . ignore)
     (set-visited-file-modtime . ignore)
-    (shell-command . ignore)
+    (shell-command . tramp-handle-shell-command)
+    (start-file-process . tramp-smb-handle-start-file-process)
     (substitute-in-file-name . tramp-smb-handle-substitute-in-file-name)
     (unhandled-file-name-directory . tramp-handle-unhandled-file-name-directory)
     (vc-registered . ignore)
@@ -210,6 +222,29 @@ See `tramp-actions-before-shell' for more info.")
   "Alist of handler functions for Tramp SMB method.
 Operations not mentioned here will be handled by the default Emacs primitives.")
 
+;; Options for remote processes via winexe.
+(defcustom tramp-smb-winexe-program "winexe"
+  "*Name of winexe client to run.
+If it isn't found in the local $PATH, the absolute path of winexe
+shall be given.  This is needed for remote processes."
+  :group 'tramp
+  :type 'string
+  :version "24.2")
+
+(defcustom tramp-smb-winexe-shell-command "powershell.exe"
+  "*Shell to be used for processes on remote machines.
+This must be Powershell V2 compatible."
+  :group 'tramp
+  :type 'string
+  :version "24.2")
+
+(defcustom tramp-smb-winexe-shell-command-switch "-file -"
+  "*Command switch used together with `tramp-smb-winexe-shell-command'.
+This can be used to disable echo etc."
+  :group 'tramp
+  :type 'string
+  :version "24.2")
+
 ;;;###tramp-autoload
 (defsubst tramp-smb-file-name-p (filename)
   "Check if it's a filename for SMB servers."
@@ -490,45 +525,46 @@ PRESERVE-UID-GID and PRESERVE-SELINUX-CONTEXT are completely ignored."
 (defun tramp-smb-handle-file-attributes (filename &optional id-format)
   "Like `file-attributes' for Tramp files."
   (unless id-format (setq id-format 'integer))
-  (with-parsed-tramp-file-name filename nil
-    (with-file-property v localname (format "file-attributes-%s" id-format)
-      (if (and (tramp-smb-get-share v) (tramp-smb-get-stat-capability v))
-	  (tramp-smb-do-file-attributes-with-stat v id-format)
-	;; Reading just the filename entry via "dir localname" is not
-	;; possible, because when filename is a directory, some
-	;; smbclient versions return the content of the directory, and
-	;; other versions don't.  Therefore, the whole content of the
-	;; upper directory is retrieved, and the entry of the filename
-	;; is extracted from.
-	(let* ((entries (tramp-smb-get-file-entries
-			 (file-name-directory filename)))
-	       (entry (assoc (file-name-nondirectory filename) entries))
-	       (uid (if (equal id-format 'string) "nobody" -1))
-	       (gid (if (equal id-format 'string) "nogroup" -1))
-	       (inode (tramp-get-inode v))
-	       (device (tramp-get-device v)))
+  (ignore-errors
+    (with-parsed-tramp-file-name filename nil
+      (with-file-property v localname (format "file-attributes-%s" id-format)
+	(if (and (tramp-smb-get-share v) (tramp-smb-get-stat-capability v))
+	    (tramp-smb-do-file-attributes-with-stat v id-format)
+	  ;; Reading just the filename entry via "dir localname" is not
+	  ;; possible, because when filename is a directory, some
+	  ;; smbclient versions return the content of the directory, and
+	  ;; other versions don't.  Therefore, the whole content of the
+	  ;; upper directory is retrieved, and the entry of the filename
+	  ;; is extracted from.
+	  (let* ((entries (tramp-smb-get-file-entries
+			   (file-name-directory filename)))
+		 (entry (assoc (file-name-nondirectory filename) entries))
+		 (uid (if (equal id-format 'string) "nobody" -1))
+		 (gid (if (equal id-format 'string) "nogroup" -1))
+		 (inode (tramp-get-inode v))
+		 (device (tramp-get-device v)))
 
-	  ;; Check result.
-	  (when entry
-	    (list (and (string-match "d" (nth 1 entry))
-		       t)       ;0 file type
-		  -1	        ;1 link count
-		  uid	        ;2 uid
-		  gid	        ;3 gid
-		  '(0 0)	;4 atime
-		  (nth 3 entry) ;5 mtime
-		  '(0 0)	;6 ctime
-		  (nth 2 entry) ;7 size
-		  (nth 1 entry) ;8 mode
-		  nil	        ;9 gid weird
-		  inode	        ;10 inode number
-		  device))))))) ;11 file system number
+	    ;; Check result.
+	    (when entry
+	      (list (and (string-match "d" (nth 1 entry))
+			 t)        ;0 file type
+		    -1	           ;1 link count
+		    uid	           ;2 uid
+		    gid	           ;3 gid
+		    '(0 0)	   ;4 atime
+		    (nth 3 entry)  ;5 mtime
+		    '(0 0)	   ;6 ctime
+		    (nth 2 entry)  ;7 size
+		    (nth 1 entry)  ;8 mode
+		    nil	           ;9 gid weird
+		    inode	   ;10 inode number
+		    device)))))))) ;11 file system number
 
 (defun tramp-smb-do-file-attributes-with-stat (vec &optional id-format)
   "Implement `file-attributes' for Tramp files using stat command."
   (tramp-message
    vec 5 "file attributes with stat: %s" (tramp-file-name-localname vec))
-  (with-current-buffer (tramp-get-buffer vec)
+  (with-current-buffer (tramp-get-connection-buffer vec)
     (let* (size id link uid gid atime mtime ctime mode inode)
       (when (tramp-smb-send-command
 	     vec (format "stat \"%s\"" (tramp-smb-get-localname vec)))
@@ -834,6 +870,127 @@ target of the symlink differ."
 	 "error with make-symbolic-link, see buffer `%s' for details"
 	 (buffer-name))))))
 
+(defun tramp-smb-handle-process-file
+  (program &optional infile destination display &rest args)
+  "Like `process-file' for Tramp files."
+  ;; The implementation is not complete yet.
+  (when (and (numberp destination) (zerop destination))
+    (error "Implementation does not handle immediate return"))
+
+  (with-parsed-tramp-file-name default-directory nil
+    (let* ((name (file-name-nondirectory program))
+	   (name1 name)
+	   (i 0)
+	   input tmpinput outbuf command ret)
+
+      ;; Determine input.
+      (when infile
+	(setq infile (expand-file-name infile))
+	(if (tramp-equal-remote default-directory infile)
+	    ;; INFILE is on the same remote host.
+	    (setq input (with-parsed-tramp-file-name infile nil localname))
+	  ;; INFILE must be copied to remote host.
+	  (setq input (tramp-make-tramp-temp-file v)
+		tmpinput (tramp-make-tramp-file-name method user host input))
+	  (copy-file infile tmpinput t))
+	;; Transform input into a filename powershell does understand.
+	(setq input (format "//%s%s" host input)))
+
+      ;; Determine output.
+      (cond
+       ;; Just a buffer.
+       ((bufferp destination)
+	(setq outbuf destination))
+       ;; A buffer name.
+       ((stringp destination)
+	(setq outbuf (get-buffer-create destination)))
+       ;; (REAL-DESTINATION ERROR-DESTINATION)
+       ((consp destination)
+	;; output.
+	(cond
+	 ((bufferp (car destination))
+	  (setq outbuf (car destination)))
+	 ((stringp (car destination))
+	  (setq outbuf (get-buffer-create (car destination))))
+	 ((car destination)
+	  (setq outbuf (current-buffer))))
+	;; stderr.
+	(tramp-message v 2 "%s" "STDERR not supported"))
+       ;; 't
+       (destination
+	(setq outbuf (current-buffer))))
+
+      ;; Construct command.
+      (setq command (mapconcat 'identity (cons program args) " ")
+	    command (if input
+			(format
+			 "get-content %s | & %s"
+			 (tramp-smb-shell-quote-argument input) command)
+		      (format "& %s" command)))
+
+      (while (get-process name1)
+	;; NAME must be unique as process name.
+	(setq i (1+ i)
+	      name1 (format "%s<%d>" name i)))
+
+      ;; Set the new process properties.
+      (tramp-set-connection-property v "process-name" name1)
+      (tramp-set-connection-property
+       v "process-buffer"
+       (or outbuf (generate-new-buffer tramp-temp-buffer-name)))
+
+      ;; Call it.
+      (condition-case nil
+	  (with-current-buffer (tramp-get-connection-buffer v)
+	    ;; Preserve buffer contents.
+	    (narrow-to-region (point-max) (point-max))
+	    (tramp-smb-call-winexe v)
+	    (when (tramp-smb-get-share v)
+	      (tramp-smb-send-command
+	       v (format "cd \"//%s%s\"" host (file-name-directory localname))))
+	    (tramp-smb-send-command v command)
+	    ;; Preserve command output.
+	    (narrow-to-region (point-max) (point-max))
+	    (let ((p (tramp-get-connection-process v)))
+	      (tramp-smb-send-command v "exit $lasterrorcode")
+	      (while (memq (process-status p) '(run open))
+		(sleep-for 0.1)
+		(setq ret (process-exit-status p))))
+	    (delete-region (point-min) (point-max))
+	    (widen))
+
+	;; When the user did interrupt, we should do it also.  We use
+	;; return code -1 as marker.
+	(quit
+	 (setq ret -1))
+	;; Handle errors.
+	(error
+	 (setq ret 1)))
+
+      ;; We should show the output anyway.
+      (when (and outbuf display) (display-buffer outbuf))
+
+      ;; Cleanup.  We remove all file cache values for the connection,
+      ;; because the remote process could have changed them.
+      (tramp-set-connection-property v "process-name" nil)
+      (tramp-set-connection-property v "process-buffer" nil)
+      (when tmpinput (delete-file tmpinput))
+      (unless outbuf
+	(kill-buffer (tramp-get-connection-property v "process-buffer" nil)))
+
+      ;; `process-file-side-effects' has been introduced with GNU
+      ;; Emacs 23.2.  If set to `nil', no remote file will be changed
+      ;; by `program'.  If it doesn't exist, we assume its default
+      ;; value `t'.
+      (unless (and (boundp 'process-file-side-effects)
+		   (not (symbol-value 'process-file-side-effects)))
+	(tramp-flush-directory-property v ""))
+
+      ;; Return exit status.
+      (if (equal ret -1)
+	  (keyboard-quit)
+	ret))))
+
 (defun tramp-smb-handle-rename-file
   (filename newname &optional ok-if-already-exists)
   "Like `rename-file' for Tramp files."
@@ -885,6 +1042,54 @@ target of the symlink differ."
 	(tramp-error
 	 v 'file-error "Error while changing file's mode %s" filename)))))
 
+;; We use BUFFER also as connection buffer during setup. Because of
+;; this, its original contents must be saved, and restored once
+;; connection has been setup.
+(defun tramp-smb-handle-start-file-process (name buffer program &rest args)
+  "Like `start-file-process' for Tramp files."
+  (with-parsed-tramp-file-name default-directory nil
+    (let ((command (mapconcat 'identity (cons program args) " "))
+	  (bmp (and (buffer-live-p buffer) (buffer-modified-p buffer)))
+	  (name1 name)
+	  (i 0))
+      (unwind-protect
+	  (save-excursion
+	    (save-restriction
+	      (unless buffer
+		;; BUFFER can be nil.  We use a temporary buffer.
+		(setq buffer (generate-new-buffer tramp-temp-buffer-name)))
+	      (while (get-process name1)
+		;; NAME must be unique as process name.
+		(setq i (1+ i)
+		      name1 (format "%s<%d>" name i)))
+	      ;; Set the new process properties.
+	      (tramp-set-connection-property v "process-name" name1)
+	      (tramp-set-connection-property v "process-buffer" buffer)
+	      ;; Activate narrowing in order to save BUFFER contents.
+	      (with-current-buffer (tramp-get-connection-buffer v)
+		(let ((buffer-undo-list t))
+		  (narrow-to-region (point-max) (point-max))
+		  (tramp-smb-call-winexe v)
+		  (when (tramp-smb-get-share v)
+		    (tramp-smb-send-command
+		     v (format
+			"cd \"//%s%s\""
+			host (file-name-directory localname))))
+		  (tramp-message v 6 "(%s); exit" command)
+		  (tramp-send-string v command)))
+	      ;; Return value.
+	      (tramp-get-connection-process v)))
+
+	;; Save exit.
+	(with-current-buffer (tramp-get-connection-buffer v)
+	  (if (string-match tramp-temp-buffer-name (buffer-name))
+	      (progn
+		(set-process-buffer (tramp-get-connection-process v) nil)
+		(kill-buffer (current-buffer)))
+	    (set-buffer-modified-p bmp)))
+	(tramp-set-connection-property v "process-name" nil)
+	(tramp-set-connection-property v "process-buffer" nil)))))
+
 (defun tramp-smb-handle-substitute-in-file-name (filename)
   "Like `handle-substitute-in-file-name' for Tramp files.
 \"//\" substitutes only in the local filename part.  Catches
@@ -988,7 +1193,7 @@ Result is a list of (LOCALNAME MODE SIZE MONTH DAY TIME YEAR)."
   (with-parsed-tramp-file-name (file-name-as-directory directory) nil
     (setq localname (or localname "/"))
     (with-file-property v localname "file-entries"
-      (with-current-buffer (tramp-get-buffer v)
+      (with-current-buffer (tramp-get-connection-buffer v)
 	(let* ((share (tramp-smb-get-share v))
 	       (cache (tramp-get-connection-property v "share-cache" nil))
 	       res entry)
@@ -1176,7 +1381,7 @@ Result is the list (LOCALNAME MODE SIZE MTIME)."
 	  (tramp-get-connection-process vec) "cifs-capabilities"
 	(save-match-data
 	  (when (tramp-smb-send-command vec "posix")
-	    (with-current-buffer (tramp-get-buffer vec)
+	    (with-current-buffer (tramp-get-connection-buffer vec)
 	      (goto-char (point-min))
 	      (when
 		  (re-search-forward "Server supports CIFS capabilities" nil t)
@@ -1205,18 +1410,20 @@ Returns nil if there has been an error message from smbclient."
   (tramp-send-string vec command)
   (tramp-smb-wait-for-output vec))
 
-(defun tramp-smb-maybe-open-connection (vec)
+(defun tramp-smb-maybe-open-connection (vec &optional argument)
   "Maybe open a connection to HOST, log in as USER, using `tramp-smb-program'.
 Does not do anything if a connection is already open, but re-opens the
-connection if a previous connection has died for some reason."
+connection if a previous connection has died for some reason.
+If ARGUMENT is non-nil, use it as argument for
+`tramp-smb-winexe-program', and suppress any checks."
   (let* ((share (tramp-smb-get-share vec))
-	 (buf (tramp-get-buffer vec))
+	 (buf (tramp-get-connection-buffer vec))
 	 (p (get-buffer-process buf)))
 
     ;; Check whether we still have the same smbclient version.
     ;; Otherwise, we must delete the connection cache, because
     ;; capabilities migh have changed.
-    (unless (processp p)
+    (unless (or argument (processp p))
       (let ((default-directory (tramp-compat-temporary-file-directory))
 	    (command (concat tramp-smb-program " -V")))
 
@@ -1260,9 +1467,10 @@ connection if a previous connection has died for some reason."
     ;; Check whether it is still the same share.
     (unless
 	(and p (processp p) (memq (process-status p) '(run open))
-	     (string-equal
-	      share
-	      (tramp-get-connection-property p "smb-share" "")))
+	     (or argument
+		 (string-equal
+		  share
+		  (tramp-get-connection-property p "smb-share" ""))))
 
       (save-match-data
 	;; There might be unread output from checking for share names.
@@ -1277,9 +1485,13 @@ connection if a previous connection has died for some reason."
 	       (port      (tramp-file-name-port vec))
 	       args)
 
-	  (if share
-	      (setq args (list (concat "//" real-host "/" share)))
-	    (setq args (list "-g" "-L" real-host )))
+	  (cond
+	   (argument
+	    (setq args (list (concat "//" real-host))))
+	   (share
+	    (setq args (list (concat "//" real-host "/" share))))
+	   (t
+	    (setq args (list "-g" "-L" real-host ))))
 
 	  (if (not (zerop (length real-user)))
 	      (setq args (append args (list "-U" real-user)))
@@ -1289,6 +1501,8 @@ connection if a previous connection has died for some reason."
 	  (when port   (setq args (append args (list "-p" port))))
 	  (when tramp-smb-conf
 	    (setq args (append args (list "-s" tramp-smb-conf))))
+	  (when argument
+	    (setq args (append args (list argument))))
 
 	  ;; OK, let's go.
 	  (tramp-with-progress-reporter
@@ -1302,8 +1516,11 @@ connection if a previous connection has died for some reason."
 		   (p (let ((default-directory
 			      (tramp-compat-temporary-file-directory)))
 			(apply #'start-process
-			       (tramp-buffer-name vec) (tramp-get-buffer vec)
-			       tramp-smb-program args))))
+			       (tramp-get-connection-name vec)
+			       (tramp-get-connection-buffer vec)
+			       (if argument
+				   tramp-smb-winexe-program tramp-smb-program)
+			       args))))
 
 	      (tramp-message
 	       vec 6 "%s" (mapconcat 'identity (process-command p) " "))
@@ -1317,25 +1534,26 @@ connection if a previous connection has died for some reason."
 	      ;; Play login scenario.
 	      (tramp-process-actions
 	       p vec nil
-	       (if share
+	       (if (or argument share)
 		   tramp-smb-actions-with-share
 		 tramp-smb-actions-without-share))
 
 	      ;; Check server version.
-	      (with-current-buffer (tramp-get-connection-buffer vec)
-		(goto-char (point-min))
-		(search-forward-regexp
-		 "Domain=\\[[^]]*\\] OS=\\[[^]]*\\] Server=\\[[^]]*\\]" nil t)
-		(let ((smbserver-version (match-string 0)))
-		  (unless
-		      (string-equal
-		       smbserver-version
-		       (tramp-get-connection-property
-			vec "smbserver-version" smbserver-version))
-		    (tramp-flush-directory-property vec "")
-		    (tramp-flush-connection-property vec))
-		  (tramp-set-connection-property
-		   vec "smbserver-version" smbserver-version)))
+	      (unless argument
+		(with-current-buffer (tramp-get-connection-buffer vec)
+		  (goto-char (point-min))
+		  (search-forward-regexp
+		   "Domain=\\[[^]]*\\] OS=\\[[^]]*\\] Server=\\[[^]]*\\]" nil t)
+		  (let ((smbserver-version (match-string 0)))
+		    (unless
+			(string-equal
+			 smbserver-version
+			 (tramp-get-connection-property
+			  vec "smbserver-version" smbserver-version))
+		      (tramp-flush-directory-property vec "")
+		      (tramp-flush-connection-property vec))
+		    (tramp-set-connection-property
+		     vec "smbserver-version" smbserver-version))))
 
 	      ;; Set chunksize.  Otherwise, `tramp-send-string' might
 	      ;; try it itself.
@@ -1347,17 +1565,18 @@ connection if a previous connection has died for some reason."
 (defun tramp-smb-wait-for-output (vec)
   "Wait for output from smbclient command.
 Returns nil if an error message has appeared."
-  (with-current-buffer (tramp-get-buffer vec)
+  (with-current-buffer (tramp-get-connection-buffer vec)
     (let ((p (get-buffer-process (current-buffer)))
 	  (found (progn (goto-char (point-min))
 			(re-search-forward tramp-smb-prompt nil t)))
 	  (err   (progn (goto-char (point-min))
-			(re-search-forward tramp-smb-errors nil t))))
+			(re-search-forward tramp-smb-errors nil t)))
+	  buffer-read-only)
 
       ;; Algorithm: get waiting output.  See if last line contains
-      ;; tramp-smb-prompt sentinel or tramp-smb-errors strings.
+      ;; `tramp-smb-prompt' sentinel or `tramp-smb-errors' strings.
       ;; If not, wait a bit and again get waiting output.
-      (while (and (not found) (not err))
+      (while (and (not found) (not err) (memq (process-status p) '(run open)))
 
 	;; Accept pending output.
 	(tramp-accept-process-output p)
@@ -1380,10 +1599,68 @@ Returns nil if an error message has appeared."
 	(goto-char (point-min))
 	(setq found (re-search-forward tramp-smb-prompt nil t)))
 
-      ;; Return value is whether no error message has appeared.
       (tramp-message vec 6 "\n%s" (buffer-string))
+
+      ;; Remove prompt.
+      (when found
+	(goto-char (point-max))
+	(re-search-backward tramp-smb-prompt nil t)
+	(delete-region (point) (point-max)))
+
+      ;; Return value is whether no error message has appeared.
       (not err))))
 
+(defun tramp-smb-kill-winexe-function ()
+  "Send SIGKILL to the winexe process."
+  (ignore-errors
+    (let ((p (get-buffer-process (current-buffer))))
+      (when (and p (processp p) (memq (process-status p) '(run open)))
+	(signal-process (process-id p) 'SIGINT)))))
+
+(defun tramp-smb-call-winexe (vec)
+  "Apply a remote command, if possible, using `tramp-smb-winexe-program'."
+
+  ;; We call `tramp-get-buffer' in order to get a debug buffer for
+  ;; messages.
+  (tramp-get-buffer vec)
+
+  ;; Check for program.
+  (unless (let ((default-directory
+		  (tramp-compat-temporary-file-directory)))
+	    (executable-find tramp-smb-winexe-program))
+    (tramp-error
+     vec 'file-error "Cannot find program: %s" tramp-smb-winexe-program))
+
+  ;; winexe does not supports ports.
+  (when (tramp-file-name-port vec)
+    (tramp-error vec 'file-error "Port not supported for remote processes"))
+
+  (tramp-smb-maybe-open-connection
+   vec
+   (format
+    "%s %s"
+    tramp-smb-winexe-shell-command tramp-smb-winexe-shell-command-switch))
+
+  (set (make-local-variable 'kill-buffer-hook)
+       '(tramp-smb-kill-winexe-function))
+
+  ;; Suppress "^M".  Shouldn't we specify utf8?
+  (set-process-coding-system (tramp-get-connection-process vec) 'raw-text-dos)
+
+  ;; Set width to 128.  This avoids mixing prompt and long error messages.
+  (tramp-smb-send-command vec "$rawui = (Get-Host).UI.RawUI")
+  (tramp-smb-send-command vec "$bufsize = $rawui.BufferSize")
+  (tramp-smb-send-command vec "$winsize = $rawui.WindowSize")
+  (tramp-smb-send-command vec "$bufsize.Width = 128")
+  (tramp-smb-send-command vec "$winsize.Width = 128")
+  (tramp-smb-send-command vec "$rawui.BufferSize = $bufsize")
+  (tramp-smb-send-command vec "$rawui.WindowSize = $winsize"))
+
+(defun tramp-smb-shell-quote-argument (s)
+  "Similar to `shell-quote-argument', but uses windows cmd syntax."
+  (let ((system-type 'ms-dos))
+    (shell-quote-argument s)))
+
 (add-hook 'tramp-unload-hook
 	  (lambda ()
 	    (unload-feature 'tramp-smb 'force)))
@@ -1393,12 +1670,11 @@ Returns nil if an error message has appeared."
 ;;; TODO:
 
 ;; * Error handling in case password is wrong.
-;; * Read password from "~/.netrc".
 ;; * Return more comprehensive file permission string.
 ;; * Try to remove the inclusion of dummy "" directory.  Seems to be at
 ;;   several places, especially in `tramp-smb-handle-insert-directory'.
 ;; * (RMS) Use unwind-protect to clean up the state so as to make the state
 ;;   regular again.
-;; * Make it multi-hop capable.
+;; * Ignore case in file names.
 
 ;;; tramp-smb.el ends here
